about summary refs log tree commit diff
path: root/scrape.h
diff options
context:
space:
mode:
authorLeah Neukirchen <leah@vuxu.org>2024-07-10 18:58:44 +0200
committerLeah Neukirchen <leah@vuxu.org>2024-07-10 18:58:44 +0200
commitd2daffcdcd51ecd79e79c0c22f7936f037b637c1 (patch)
treebd71a6da57e5d063bb143d4e3731fa85cc9cdea0 /scrape.h
parent653dc9cd6836d505abc1cf988b7e7186ff742f6d (diff)
downloadnano-exporter-d2daffcdcd51ecd79e79c0c22f7936f037b637c1.tar.gz
nano-exporter-d2daffcdcd51ecd79e79c0c22f7936f037b637c1.tar.xz
nano-exporter-d2daffcdcd51ecd79e79c0c22f7936f037b637c1.zip
support binding to a specific host address
Diffstat (limited to 'scrape.h')
-rw-r--r--scrape.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/scrape.h b/scrape.h
index f163e52..df1d38a 100644
--- a/scrape.h
+++ b/scrape.h
@@ -34,8 +34,8 @@ struct collector {
   bool has_args;
 };
 
-/** Sets up a scrape server listening at the given port. */
-scrape_server *scrape_listen(const char *port);
+/** Sets up a scrape server listening at the given host:port. */
+scrape_server *scrape_listen(const char *host, const char *port);
 
 /** Enters a loop serving scrape requests of the provided collectors. */
 void scrape_serve(scrape_server *server, unsigned ncoll, const struct collector *coll[], void *coll_ctx[]);